
============
Config
============
.. currentmodule:: polars

.. autosummary::
   :toctree: api/

    Config.set_utf8_tables
    Config.set_ascii_tables
    Config.set_tbl_width_chars
    Config.set_tbl_rows
    Config.set_tbl_cols
    Config.set_global_string_cache
    Config.unset_global_string_cache
    toggle_string_cache
    StringCache
